@@ -20,7 +20,7 @@ import org.gnu.gtk.ToolBar;
 import org.gnu.gtk.VBox;
 import org.gnu.gtk.Widget;
 import org.gnu.gtk.Window;
-import org.gnu.javagnome.Handle;
+import org.gnu.glib.Handle;
 
 /**
  * The App widget is the main window of a GNOME application. It is
@@ -28,10 +28,11 @@ import org.gnu.javagnome.Handle;
  * includes facilities for attaching menus, toolbars, a status bar, and
  * widgets that can be docked.
  */
+
 public class App extends Window {
 
 	/**
-	 * Instinates a new Application window with the indicated name and title.
+	 * Instantiates a new Application window with the indicated name and title.
 	 * @param appname The name of the application.
 	 * @param title The title of the application window.  The title can be
 	 *              null, in which case the window's title will not be set.
@@ -49,13 +50,9 @@ public class App extends Window {
 	 * @return The dock.
 	 */
 	public Widget getDock() {
+        checkState();
 		Handle hndl = getDock(getHandle());
-		if (null == hndl)
-			return null;
-		GObject obj = getGObjectFromHandle(hndl);
-		if (null != obj)
-			return (Widget)obj;
-		return new Widget(hndl);
+		return Widget.getWidget(hndl);
 	}
 
 	/**
@@ -63,7 +60,8 @@ public class App extends Window {
 	 * @return The accelorator group.
 	 */
 	public AccelGroup getAccelGroup() {
-		return new AccelGroup(getAccelGroup(getHandle()));
+        checkState();
+		return AccelGroup.getAccelGroup(getAccelGroup(getHandle()));
 	}
 
 	/**
@@ -71,22 +69,18 @@ public class App extends Window {
 	 * @return The MenuBar.
 	 */
 	public MenuBar getMenuBar() {
+        checkState();
 		Handle hndl = getMenubar(getHandle());
-		GObject obj = getGObjectFromHandle(hndl);
-		if (null != obj)
-			return (MenuBar)obj;
-		return new MenuBar(hndl);
+		return MenuBar.getMenuBar(hndl);
 	}
 	
 	/**
 	 * Returns the contents of the App.
 	 */
 	public Widget getContents() {
+        checkState();
 		Handle hndl = getContents(getHandle());
-		GObject obj = getGObjectFromHandle(hndl);
-		if (null != obj)
-			return (Widget)obj;
-		return new Widget(hndl);
+		return Widget.getWidget(hndl);
 	}
 
 	/**
@@ -94,6 +88,7 @@ public class App extends Window {
 	 * @return The name of the application.
 	 */
 	public String getName() {
+        checkState();
 		return getName(getHandle());
 	}
 
@@ -102,6 +97,7 @@ public class App extends Window {
 	 * @return The prefix for gnome-config.
 	 */
 	public String getPrefix() {
+        checkState();
 		return getPrefix(getHandle());
 	}
 
@@ -110,11 +106,9 @@ public class App extends Window {
 	 * @return The status bar.
 	 */
 	public StatusBar getStatusBar() {
+        checkState();
 		Handle hndl = getStatusbar(getHandle());
-		GObject obj = getGObjectFromHandle(hndl);
-		if (null != obj)
-			return (StatusBar)obj;
-		return new StatusBar(hndl);
+		return StatusBar.getStatusBar(hndl);
 	}
 
 	/**
@@ -122,11 +116,9 @@ public class App extends Window {
 	 * @return The VBox.
 	 */
 	public VBox getVBox() {
+        checkState();
 		Handle hndl = getVbox(getHandle());
-		GObject obj = getGObjectFromHandle(hndl);
-		if (null != obj)
-			return (VBox)obj;
-		return new VBox(hndl);
+		return VBox.getVBox(hndl);
 	}
 
 	/**
@@ -136,6 +128,7 @@ public class App extends Window {
 	 &         automatically, else false.
 	 */
 	public boolean layoutConfig() {
+        checkState();
 		return getEnableLayoutConfig(getHandle());
 	}
 
@@ -146,6 +139,7 @@ public class App extends Window {
 	 *                automatically, else false.
 	 */
 	public void layoutConfig(boolean enabled) {
+        checkState();
 		gnome_app_enable_layout_config(getHandle(), enabled);
 	}
 
@@ -154,6 +148,7 @@ public class App extends Window {
 	 * @param contents The widget that contains the content of the window.
 	 */
 	public void setContent(Widget contents) {
+        checkState();
 		gnome_app_set_contents(getHandle(), contents.getHandle());
 	}
 
@@ -162,6 +157,7 @@ public class App extends Window {
 	 * @param menuBar The menu bar to be used for the window.
 	 */
 	public void setMenuBar(MenuBar menuBar) {
+        checkState();
 		gnome_app_set_menus(getHandle(), menuBar.getHandle());
 	}
 	
@@ -170,6 +166,7 @@ public class App extends Window {
 	 * @param uiinfos An array of UIInfo objects that define the menu.
 	 */
 	public void createMenus(UIInfo [] uiinfos) {
+        checkState();
 		if (uiinfos.length < 1)
 			return;
 		Handle[] hndls = new Handle[uiinfos.length];
@@ -185,6 +182,7 @@ public class App extends Window {
 	 * @param num The number of items to remove.
 	 */
 	public void removeMenus(String path, int num) {
+        checkState();
 		gnome_app_remove_menus(getHandle(), path, num);
 	}
 	
@@ -196,6 +194,7 @@ public class App extends Window {
 	 * to be inserted.
 	 */
 	public void insertMenu(String path, UIInfo [] uiinfos) {
+        checkState();
 		if (uiinfos.length < 1)
 			return;
 		Handle[] hndls = new Handle[uiinfos.length];
@@ -209,6 +208,7 @@ public class App extends Window {
 	 * @param toolBar The tool bar to be used for the window.
 	 */
 	public void setToolBar(ToolBar toolBar) {
+        checkState();
 		gnome_app_set_toolbar(getHandle(), toolBar.getHandle());
 	}
 
@@ -217,6 +217,7 @@ public class App extends Window {
 	 * @param uiinfos An array of UIInfo objects that define the toolbar.
 	 */
 	public void createToolBar(UIInfo [] uiinfos) {
+        checkState();
 		if (uiinfos.length < 1)
 			return;
 		Handle[] hndls = new Handle[uiinfos.length];
@@ -230,6 +231,7 @@ public class App extends Window {
 	 * @param appBar The app bar to use for the window.
 	 */
 	public void setStatusBar(AppBar appBar) {
+        checkState();
 		gnome_app_set_statusbar(getHandle(), appBar.getHandle());
 	}
 
@@ -238,6 +240,7 @@ public class App extends Window {
 	 * @param statusBar The status bar to use for the window.
 	 */
 	public void setStatusBar(StatusBar statusBar) {
+        checkState();
 		gnome_app_set_statusbar(getHandle(), statusBar.getHandle());
 	}
 
@@ -248,6 +251,7 @@ public class App extends Window {
 	 * @param container The container for the status bar.
 	 */
 	public void setStatusBar(AppBar appBar, Container container) {
+        checkState();
 		gnome_app_set_statusbar_custom(getHandle(), container.getHandle(), appBar.getHandle());
 	}
 
@@ -258,6 +262,7 @@ public class App extends Window {
 	 * @param container The container for the status bar.
 	 */
 	public void setStatusBar(StatusBar statusBar, Container container) {
+        checkState();
 		gnome_app_set_statusbar_custom(getHandle(), container.getHandle(), statusBar.getHandle());
 	}
 	
@@ -268,6 +273,7 @@ public class App extends Window {
 	 * for which the hints will be created.
 	 */
 	public void installAppBarMenuHints(AppBar appBar, UIInfo [] uiinfos) {
+        checkState();
 		Handle [] hndls= new Handle[uiinfos.length];
 		for (int i = 0; i < uiinfos.length; i++) {
 			hndls[i] = uiinfos[i].getHandle();
@@ -282,6 +288,7 @@ public class App extends Window {
 	 * for which the hints will be created.
 	 */
 	public void installStatusBarMenuHints(StatusBar statusBar, UIInfo [] uiinfos) {
+        checkState();
 		Handle [] hndls= new Handle[uiinfos.length];
 		for (int i = 0; i < uiinfos.length; i++) {
 			hndls[i] = uiinfos[i].getHandle();
@@ -295,6 +302,7 @@ public class App extends Window {
 	 * for which the hints will be created.
 	 */
 	public void installMenuHints(UIInfo [] uiinfos) {
+        checkState();
 		Handle [] hndls= new Handle[uiinfos.length];
 		for (int i = 0; i < uiinfos.length; i++) {
 			hndls[i] = uiinfos[i].getHandle();
@@ -314,7 +322,9 @@ public class App extends Window {
      * @param underline
      * @param position
      */
-	public void fillMenu(MenuShell menuShell, UIInfo[] uiinfos, AccelGroup accelGroup, boolean underline, int position) {
+	public void fillMenu(MenuShell menuShell, UIInfo[] uiinfos, AccelGroup
+            accelGroup, boolean underline, int position) {
+        checkState();
         Handle[] hndls = new Handle[uiinfos.length];
         for (int i = 0; i < uiinfos.length; i++)
             hndls[i] = uiinfos[i].getHandle();
@@ -328,6 +338,7 @@ public class App extends Window {
      * @param accelGroup
 	 */
     public void fillToolbar(ToolBar toolbar, UIInfo[] uiinfos, AccelGroup accelGroup) {
+        checkState();
         Handle[] hndls = new Handle[uiinfos.length];
         for (int i = 0; i < uiinfos.length; i++)
             hndls[i] = uiinfos[i].getHandle();
@@ -341,12 +352,9 @@ public class App extends Window {
      * @param numItems
      */
     public void removeMenuRange(String path, int start, int numItems) {
+        checkState();
         gnome_app_remove_menu_range(getHandle(), path, start, numItems);
     }
-
-    
-    
-    
     
     /**
 	 * Display a simple message in an OK dialog or the status bar.  Requires
@@ -417,7 +425,6 @@ public class App extends Window {
 		return new Type(gnome_app_get_type());
 	}
 
-
 	native static final protected String getName(Handle cptr);
 	native static final protected String getPrefix(Handle cptr);
 	native static final protected Handle getDock(Handle cptr);
