@@ -13,14 +13,13 @@ import java.util.Vector;
 
 import org.gnu.glib.EventMap;
 import org.gnu.glib.EventType;
-import org.gnu.glib.GObject;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gnome.event.AppBarEvent;
 import org.gnu.gnome.event.AppBarListener;
 import org.gnu.gtk.HBox;
 import org.gnu.gtk.ProgressBar;
 import org.gnu.gtk.StatusBar;
-import org.gnu.javagnome.Handle;
 
 /**
  * The AppBar widget is a progress bar with a textual annotation.
@@ -66,10 +65,7 @@ public class AppBar extends HBox {
 	 */
 	public ProgressBar getProgressBar() {
 		Handle hndl = gnome_appbar_get_progress(getHandle());
-		GObject obj = getGObjectFromHandle(hndl);
-		if (null != obj)
-			return (ProgressBar)obj;
-		return new ProgressBar(hndl);
+		return ProgressBar.getProgressBar(hndl);
 	}
 
 	/**
@@ -144,7 +140,7 @@ public class AppBar extends HBox {
 	 * Return the StatusBar widget contained in this AppBar.
 	 */
 	public StatusBar getStatusBar() {
-		return new StatusBar(gnome_appbar_get_status(getHandle()));
+		return StatusBar.getStatusBar(gnome_appbar_get_status(getHandle()));
 	}
 
 	/**
@@ -237,7 +233,6 @@ public class AppBar extends HBox {
 		anEvtMap.addEvent("clear_prompt", "handleClearPrompt", AppBarEvent.Type.CLEAR_PROMPT, AppBarListener.class);
 	}
 
-
 	native static final protected int gnome_appbar_get_type();
 	native static final protected Handle gnome_appbar_new(boolean hasProgress, boolean hasStatus, int interactivity);
 	native static final protected void gnome_appbar_set_status(Handle appbar, String status);
