@@ -11,11 +11,11 @@ package org.gnu.gnome;
 
 import org.gnu.glib.GObject;
 import org.gnu.glib.Type;
-import org.gnu.javagnome.Handle;
+import org.gnu.glib.Handle;
 
 /**
- * The GnomeCanvasItem is the base class of all items that a
- * GnomeCanvas displays.
+ * The CanvasItem is the base class of all items that a
+ * Canvas displays.
  */
 public class CanvasItem extends GObject {
 	
@@ -29,6 +29,20 @@ public class CanvasItem extends GObject {
 	CanvasItem(Handle handle) {
 		super(handle);
 	}
+    
+    static CanvasItem getCanvasItem(Handle handle) {
+        if (handle == null) {
+            return null;
+        }
+        
+        CanvasItem obj = (CanvasItem) GObject.getGObjectFromHandle(handle);
+        
+        if (obj == null) {
+            obj = new CanvasItem(handle);
+        }
+        
+        return obj;
+    }
 
 	/**
 	 * Apply an absolute affine transformation to the item.
@@ -52,10 +66,7 @@ public class CanvasItem extends GObject {
 	 */
 	public Canvas getCanvas() {
 		Handle hndl = getCanvas(getHandle());
-		GObject obj = getGObjectFromHandle(hndl);
-		if (null != obj)
-			return (Canvas)obj;
-		return new Canvas(hndl);
+		return Canvas.getCanvas(hndl);
 	}
 
 	/**
@@ -64,10 +75,7 @@ public class CanvasItem extends GObject {
 	 */
 	public CanvasGroup getParent() {
 		Handle hndl = getParent(getHandle());
-		GObject obj = getGObjectFromHandle(hndl);
-		if (null != obj)
-			return (CanvasGroup)obj;
-		return new CanvasGroup(hndl);
+		return CanvasGroup.getCanvasGroup(hndl);
 	}
 
 	/**
