@@ -13,11 +13,12 @@ import java.util.Date;
 import java.util.Vector;
 
 import org.gnu.glib.EventMap;
+import org.gnu.glib.EventType;
 import org.gnu.glib.Type;
 import org.gnu.gnome.event.DateEditEvent;
 import org.gnu.gnome.event.DateEditListener;
 import org.gnu.gtk.HBox;
-import org.gnu.gtk.event.GtkEventType;
+import org.gnu.glib.Handle;
 
 /**
  * A control which allows the user to select a date.
@@ -38,15 +39,13 @@ public class DateEdit extends HBox {
 	 */
 	public DateEdit(java.util.Date date, boolean timeDisplay, boolean use24fmt) {
 		super(gnome_date_edit_new(date.getTime() / 1000, timeDisplay, use24fmt));
-		initializeEventHandlers();
 	}
 
 	/**
 	 * Construct a new DateEdit from a handle to a native resource.
 	 */
-	public DateEdit(int handle) {
+	public DateEdit(Handle handle) {
 		super(handle);
-		initializeEventHandlers();
 	}
 
 	/**
@@ -160,6 +159,8 @@ public class DateEdit extends HBox {
 		int i = findListener(dateEditListeners, listener);
 		if (i == -1) {
 			if (null == dateEditListeners) {
+				evtMap.initialize(this, DateEditEvent.Type.DATE_CHANGED);
+				evtMap.initialize(this, DateEditEvent.Type.TIME_CHANGED);
 				dateEditListeners = new Vector();
 			}
 			dateEditListeners.addElement(listener);
@@ -167,7 +168,7 @@ public class DateEdit extends HBox {
 	}
 	/**
 	 * Removes a listener
-	 * @see #addListener(DateEditListeners)
+	 * @see #addListener(DateEditListener)
 	 */
 	public void removeListener(DateEditListener listener) {
 		int i = findListener(dateEditListeners, listener);
@@ -175,6 +176,8 @@ public class DateEdit extends HBox {
 			dateEditListeners.remove(i);
 		}
 		if (0 == dateEditListeners.size()) {
+			evtMap.uninitialize(this, DateEditEvent.Type.DATE_CHANGED);
+			evtMap.uninitialize(this, DateEditEvent.Type.TIME_CHANGED);
 			dateEditListeners = null;
 		}
 	}
@@ -199,22 +202,14 @@ public class DateEdit extends HBox {
 		fireDateEditEvent(new DateEditEvent(this, DateEditEvent.Type.TIME_CHANGED));
 	}
 
-	protected void initializeEventHandlers() {
-		if (!eventsInitialized) {
-			super.initializeEventHandlers();
-			evtMap.initialize(this);
-			eventsInitialized = true;
-		}
-	}
-
 	public Class getEventListenerClass(String signal) {
 		Class cls = evtMap.getEventListenerClass(signal);
 		if (cls == null) cls = super.getEventListenerClass(signal);
 		return cls;
 	}
 
-	public GtkEventType getEventType(String signal) {
-		GtkEventType et = evtMap.getEventType(signal);
+	public EventType getEventType(String signal) {
+		EventType et = evtMap.getEventType(signal);
 		if (et == null) et = super.getEventType(signal);
 		return et;
 	}
@@ -233,19 +228,15 @@ public class DateEdit extends HBox {
 		anEvtMap.addEvent("time_changed", "handleTimeChanged", DateEditEvent.Type.TIME_CHANGED, DateEditListener.class);
 	}
 
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
+
 	native static final protected int gnome_date_edit_get_type();
-	native static final protected int gnome_date_edit_new(long the_time, boolean show_time, boolean use_24_format);
-	native static final protected int gnome_date_edit_new_flags(long the_time, int flags);
-	native static final protected void gnome_date_edit_set_time(int gde, long the_time);
-	native static final protected long gnome_date_edit_get_time(int gde);
-	native static final protected void gnome_date_edit_set_popup_range(int gde, int low_hour, int up_hour);
-	native static final protected void gnome_date_edit_set_flags(int gde, int flags);
-	native static final protected int gnome_date_edit_get_flags(int gde);
-	native static final protected long gnome_date_edit_get_initial_time(int gde);
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+	native static final protected Handle gnome_date_edit_new(long the_time, boolean show_time, boolean use_24_format);
+	native static final protected Handle gnome_date_edit_new_flags(long the_time, int flags);
+	native static final protected void gnome_date_edit_set_time(Handle gde, long the_time);
+	native static final protected long gnome_date_edit_get_time(Handle gde);
+	native static final protected void gnome_date_edit_set_popup_range(Handle gde, int low_hour, int up_hour);
+	native static final protected void gnome_date_edit_set_flags(Handle gde, int flags);
+	native static final protected int gnome_date_edit_get_flags(Handle gde);
+	native static final protected long gnome_date_edit_get_initial_time(Handle gde);
+
 }
