@@ -19,7 +19,7 @@ import org.gnu.gnome.event.FontPickerEvent;
 import org.gnu.gnome.event.FontPickerListener;
 import org.gnu.gtk.Button;
 import org.gnu.gtk.Widget;
-import org.gnu.javagnome.Handle;
+import org.gnu.glib.Handle;
 
 /**
  * The FontPicker widget is a button that, when selected, presents
@@ -27,6 +27,7 @@ import org.gnu.javagnome.Handle;
  * available fonts.
  * 
  * @deprecated
+ * @see org.gnu.gtk.FontButton
  */
 public class FontPicker extends Button {
 	/**
