@@ -10,6 +10,7 @@
 package org.gnu.gnome;
 
 import org.gnu.gtk.Dialog;
+import org.gnu.glib.Handle;
 
 /**
  */
@@ -28,57 +29,62 @@ public class PasswordDialog extends Dialog {
 	}
 	
 	public boolean runAndBlock() {
+        checkState();
 		return gnome_password_dialog_run_and_block(getHandle());
 	}
 	
 	public void setUsername(String username) {
+        checkState();
 		gnome_password_dialog_set_username(getHandle(), username);
 	}
 	
 	public String getUsername() {
+        checkState();
 		return gnome_password_dialog_get_username(getHandle());
 	}
 	
 	public void setPassword(String password) {
+        checkState();
 		gnome_password_dialog_set_password(getHandle(), password);
 	}
 	
 	public String getPassword() {
+        checkState();
 		return gnome_password_dialog_get_password(getHandle());
 	}
 	
 	public void setReadonlyUsername(boolean readonly) {
+        checkState();
 		gnome_password_dialog_set_readonly_username(getHandle(), readonly);
 	}
 	
 	public void setRemember(boolean remember) {
+        checkState();
 		gnome_password_dialog_set_remember(getHandle(), remember);
 	}
 	
 	public boolean getRemember() {
+        checkState();
 		return gnome_password_dialog_get_remember(getHandle());
 	}
 	
 	public void setShowUserpassButtons(boolean show) {
+        checkState();
 		gnome_password_dialog_set_show_userpass_buttons(getHandle(), show);
 	}
 	
-	/****************************************
-	 * BEGINNING OF JNI CODE
-	 ****************************************/
+
 	native static final protected int gnome_password_dialog_get_type();
-	native static final protected int gnome_password_dialog_new(String title, String message, String username, String password, boolean readonlyUsername);
-	native static final protected boolean gnome_password_dialog_run_and_block(int dialog);
-	native static final protected void gnome_password_dialog_set_username(int dialog, String username);
-	native static final protected void gnome_password_dialog_set_password(int dialog, String password);
-	native static final protected void gnome_password_dialog_set_readonly_username(int dialog, boolean readonly);
-	native static final protected void gnome_password_dialog_set_remember(int dialog, boolean remember);
-	native static final protected void gnome_password_dialog_set_show_userpass_buttons(int dialog, boolean show);
-	native static final protected String gnome_password_dialog_get_username(int dialog);
-	native static final protected String gnome_password_dialog_get_password(int dialog);
-	native static final protected boolean gnome_password_dialog_get_remember(int dialog);
-	/****************************************
-	 * END OF JNI CODE
-	 ****************************************/
+	native static final protected Handle gnome_password_dialog_new(String title, String message, String username, String password, boolean readonlyUsername);
+	native static final protected boolean gnome_password_dialog_run_and_block(Handle dialog);
+	native static final protected void gnome_password_dialog_set_username(Handle dialog, String username);
+	native static final protected void gnome_password_dialog_set_password(Handle dialog, String password);
+	native static final protected void gnome_password_dialog_set_readonly_username(Handle dialog, boolean readonly);
+	native static final protected void gnome_password_dialog_set_remember(Handle dialog, boolean remember);
+	native static final protected void gnome_password_dialog_set_show_userpass_buttons(Handle dialog, boolean show);
+	native static final protected String gnome_password_dialog_get_username(Handle dialog);
+	native static final protected String gnome_password_dialog_get_password(Handle dialog);
+	native static final protected boolean gnome_password_dialog_get_remember(Handle dialog);
+
 	
 }
