@@ -8,11 +8,13 @@
  */
 
 package org.gnu.gnome;
+
 import org.gnu.glib.GObject;
-import org.gnu.glib.Handle;
 import org.gnu.gtk.AccelGroup;
 import org.gnu.gtk.Menu;
 import org.gnu.gtk.Widget;
+import org.gnu.glib.Handle;
+
 /**
  * @deprecated
  */
@@ -52,11 +54,8 @@ public class PopupMenu extends Menu {
 	 * Return the AccelGroup associated with this PopupMenu.
 	 */
 	public AccelGroup getAccelGroup() {
-		Handle hndl = gnome_popup_menu_get_accel_group(getHandle());
-		GObject obj = retrieveGObject(hndl);
-		if (null != obj)
-			return (AccelGroup)obj;
-		return new AccelGroup(hndl);
+        Handle handle = gnome_popup_menu_get_accel_group(getHandle());
+		return AccelGroup.getAccelGroup(handle);
 	}
 	
 	/**
