@@ -11,7 +11,7 @@ package org.gnu.gnome;
 
 import org.gnu.glib.Type;
 import org.gnu.gtk.Dialog;
-import org.gnu.javagnome.Handle;
+import org.gnu.glib.Handle;
 
 /**
  * The GnomeScores widget displays a list of names and scores for the
