@@ -10,7 +10,7 @@
 package org.gnu.gnome;
 
 import org.gnu.glib.GObject;
-import org.gnu.javagnome.Handle;
+import org.gnu.glib.Handle;
 
 /**
  *
