@@ -10,15 +10,14 @@
 package org.gnu.gnome;
 
 import org.gnu.gdk.ModifierType;
-import org.gnu.glib.GObject;
+import org.gnu.glib.Handle;
+import org.gnu.glib.Struct;
 import org.gnu.gtk.GtkStockItem;
 import org.gnu.gtk.Widget;
 import org.gnu.gtk.event.ButtonEvent;
 import org.gnu.gtk.event.ButtonListener;
 import org.gnu.gtk.event.MenuItemEvent;
 import org.gnu.gtk.event.MenuItemListener;
-import org.gnu.javagnome.Handle;
-import org.gnu.javagnome.Struct;
 
 /**
  *
@@ -173,13 +172,7 @@ public class UIInfo extends Struct {
 
 	public Widget getWidget(){
 		Handle hndl = getWidget(getHandle());
-                if ( hndl == null || hndl.isNull() )
-			return null;
-                GObject obj = GObject.getGObjectFromHandle( hndl );
-                if (obj != null) {
-                    return (Widget)obj;
-                }
-		return new Widget(hndl);
+		return Widget.getWidget(hndl);
 	}
 
 	protected void handleMenuEvent() {
