@@ -9,7 +9,7 @@
 
 package org.gnu.gnome;
 
-import org.gnu.javagnome.Struct;
+import org.gnu.glib.Struct;
 
 public class Util extends Struct {
 	/**
