@@ -10,6 +10,7 @@
 #include <jni.h>
 #include <gnome.h>
 #include <jg_jnu.h>
+#include <gtk_java.h>
 
 #ifdef __cplusplus
 extern "C" 
@@ -58,7 +59,7 @@ GtkWidget * GnomeApp_get_dock (GnomeApp * cptr)
 JNIEXPORT jobject JNICALL Java_org_gnu_gnome_App_getDock (JNIEnv *env, jclass cls, jobject cptr) 
 {
     GnomeApp *cptr_g = (GnomeApp *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GnomeApp_get_dock (cptr_g));
+    return getGObjectHandle(env, G_OBJECT(GnomeApp_get_dock (cptr_g)));
 }
 
 GtkWidget * GnomeApp_get_statusbar (GnomeApp * cptr) 
@@ -73,7 +74,7 @@ GtkWidget * GnomeApp_get_statusbar (GnomeApp * cptr)
 JNIEXPORT jobject JNICALL Java_org_gnu_gnome_App_getStatusbar (JNIEnv *env, jclass cls, jobject cptr) 
 {
     GnomeApp *cptr_g = (GnomeApp *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GnomeApp_get_statusbar (cptr_g));
+    return getGObjectHandle(env, G_OBJECT(GnomeApp_get_statusbar (cptr_g)));
 }
 
 GtkWidget * GnomeApp_get_vbox (GnomeApp * cptr) 
@@ -88,7 +89,7 @@ GtkWidget * GnomeApp_get_vbox (GnomeApp * cptr)
 JNIEXPORT jobject JNICALL Java_org_gnu_gnome_App_getVbox (JNIEnv *env, jclass cls, jobject cptr) 
 {
     GnomeApp *cptr_g = (GnomeApp *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GnomeApp_get_vbox (cptr_g));
+    return getGObjectHandle(env, G_OBJECT(GnomeApp_get_vbox (cptr_g)));
 }
 
 GtkWidget * GnomeApp_get_menubar (GnomeApp * cptr) 
@@ -103,7 +104,7 @@ GtkWidget * GnomeApp_get_menubar (GnomeApp * cptr)
 JNIEXPORT jobject JNICALL Java_org_gnu_gnome_App_getMenubar (JNIEnv *env, jclass cls, jobject cptr) 
 {
     GnomeApp *cptr_g = (GnomeApp *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GnomeApp_get_menubar (cptr_g));
+    return getGObjectHandle(env, G_OBJECT(GnomeApp_get_menubar (cptr_g)));
 }
 
 GtkWidget * GnomeApp_get_contents (GnomeApp * cptr) 
@@ -118,7 +119,7 @@ GtkWidget * GnomeApp_get_contents (GnomeApp * cptr)
 JNIEXPORT jobject JNICALL Java_org_gnu_gnome_App_getContents (JNIEnv *env, jclass cls, jobject cptr) 
 {
     GnomeApp *cptr_g = (GnomeApp *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GnomeApp_get_contents (cptr_g));
+    return getGObjectHandle(env, G_OBJECT(GnomeApp_get_contents (cptr_g)));
 }
 
 GtkAccelGroup * GnomeApp_get_accel_group (GnomeApp * cptr) 
@@ -133,7 +134,7 @@ GtkAccelGroup * GnomeApp_get_accel_group (GnomeApp * cptr)
 JNIEXPORT jobject JNICALL Java_org_gnu_gnome_App_getAccelGroup (JNIEnv *env, jclass cls, jobject cptr)
 {
     GnomeApp *cptr_g = (GnomeApp *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GnomeApp_get_accel_group (cptr_g));
+    return getGObjectHandleAndRef(env, G_OBJECT(GnomeApp_get_accel_group (cptr_g)));
 }
 
 gboolean GnomeApp_get_enable_layout_config (GnomeApp * cptr) 
@@ -170,7 +171,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_App_gnome_1app_1new (JNIEnv *env, j
 {
     const gchar* appname_g = (*env)->GetStringUTFChars(env, appname, NULL);
     const gchar* title_g = (*env)->GetStringUTFChars(env, title, NULL);
-    jobject retval =  getHandleFromPointer(env, gnome_app_new (appname_g, title_g));
+    jobject retval =  getGObjectHandle(env, G_OBJECT(gnome_app_new (appname_g, title_g)));
     (*env)->ReleaseStringUTFChars(env, appname, appname_g);
     (*env)->ReleaseStringUTFChars(env, title, title_g);
     return retval;
@@ -325,7 +326,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_App_gnome_1app_1find_1menu_1pos (JN
     GtkWidget *parent_g = (GtkWidget *)getPointerFromHandle(env, parent);
     gint32 pos_g = (gint32) pos;
     const gchar* path_g = (*env)->GetStringUTFChars(env, path, NULL);
-    jobject retval = getHandleFromPointer(env, gnome_app_find_menu_pos (parent_g, path_g, &pos_g));
+    jobject retval = getGObjectHandle(env, G_OBJECT(gnome_app_find_menu_pos (parent_g, path_g, &pos_g)));
     (*env)->ReleaseStringUTFChars(env, path, path_g);
     return retval;
 }
@@ -557,7 +558,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_App_gnome_1app_1message (JNIEnv *en
 {
     GnomeApp *app_g = (GnomeApp *)getPointerFromHandle(env, app);
     const gchar* message_g = (*env)->GetStringUTFChars(env, message, NULL);
-    jobject retval = getHandleFromPointer(env, gnome_app_message (app_g, message_g));
+    jobject retval = getGObjectHandle(env, G_OBJECT(gnome_app_message (app_g, message_g)));
     (*env)->ReleaseStringUTFChars( env, message, message_g );
     return retval;
 }
@@ -584,7 +585,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_App_gnome_1app_1error (JNIEnv *env,
 {
     GnomeApp *app_g = (GnomeApp *)getPointerFromHandle(env, app);
     const gchar* error_g = (*env)->GetStringUTFChars(env, error, NULL);
-    jobject retval = getHandleFromPointer(env, gnome_app_error (app_g, error_g));
+    jobject retval = getGObjectHandle(env, G_OBJECT(gnome_app_error (app_g, error_g)));
     (*env)->ReleaseStringUTFChars( env, error, error_g );
     return retval;
 }
@@ -598,7 +599,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_App_gnome_1app_1warning (JNIEnv *en
 {
     GnomeApp *app_g = (GnomeApp *)getPointerFromHandle(env, app);
     const gchar* warning_g = (*env)->GetStringUTFChars(env, warning, NULL);
-    jobject retval = getHandleFromPointer(env, gnome_app_warning (app_g, warning_g));
+    jobject retval = getGObjectHandle(env, G_OBJECT(gnome_app_warning (app_g, warning_g)));
     (*env)->ReleaseStringUTFChars( env, warning, warning_g );
     return retval;
 }
