@@ -10,6 +10,7 @@
 #include <jni.h>
 #include <gnome.h>
 #include <jg_jnu.h>
+#include <gtk_java.h>
 
 #ifdef __cplusplus
 extern "C" 
@@ -312,7 +313,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gnome_Client_gnome_1client_1flush (JNIEnv *e
  */
 JNIEXPORT jobject JNICALL Java_org_gnu_gnome_Client_gnome_1client_1new (JNIEnv *env, jclass cls) 
 {
-    return getHandleFromPointer(env, gnome_client_new ());
+    return getGObjectHandle(env, G_OBJECT(gnome_client_new ()));
 }
 
 /*
