@@ -10,6 +10,7 @@
 #include <jni.h>
 #include <gnome.h>
 #include <jg_jnu.h>
+#include <gtk_java.h>
 
 #ifdef __cplusplus
 extern "C" 
@@ -29,7 +30,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_DruidPageStandard_getVbox (JNIEnv *
     jobject cptr) 
 {
     GnomeDruidPageStandard *cptr_g = (GnomeDruidPageStandard *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GnomeDruidPageStandard_get_vbox (cptr_g));
+    return getGObjectHandle(env, G_OBJECT(GnomeDruidPageStandard_get_vbox (cptr_g)));
 }
 
 gchar * GnomeDruidPageStandard_get_title (GnomeDruidPageStandard * cptr) 
@@ -63,7 +64,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_DruidPageStandard_getLogo (JNIEnv *
     jobject cptr) 
 {
     GnomeDruidPageStandard *cptr_g = (GnomeDruidPageStandard *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GnomeDruidPageStandard_get_logo (cptr_g));
+    return getGObjectHandleAndRef(env, G_OBJECT(GnomeDruidPageStandard_get_logo (cptr_g)));
 }
 
 GdkPixbuf * GnomeDruidPageStandard_get_top_watermark (GnomeDruidPageStandard * cptr) 
@@ -79,7 +80,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_DruidPageStandard_getTopWatermark (
     jclass cls, jobject cptr) 
 {
     GnomeDruidPageStandard *cptr_g = (GnomeDruidPageStandard *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GnomeDruidPageStandard_get_top_watermark (cptr_g));
+    return getGObjectHandleAndRef(env, G_OBJECT(GnomeDruidPageStandard_get_top_watermark (cptr_g)));
 }
 
 GdkColor * GnomeDruidPageStandard_get_title_foreground (GnomeDruidPageStandard * cptr) 
@@ -95,7 +96,9 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_DruidPageStandard_getTitleForegroun
     jclass cls, jobject cptr) 
 {
     GnomeDruidPageStandard *cptr_g = (GnomeDruidPageStandard *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GnomeDruidPageStandard_get_title_foreground (cptr_g));
+    return getGBoxedHandle(env, GnomeDruidPageStandard_get_title_foreground (cptr_g),
+    		GDK_TYPE_COLOR, (GBoxedCopyFunc) gdk_color_copy,
+    		(GBoxedFreeFunc) gdk_color_free);
 }
 
 GdkColor * GnomeDruidPageStandard_get_background (GnomeDruidPageStandard * cptr) 
@@ -111,7 +114,9 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_DruidPageStandard_getBackground (JN
     cls, jobject cptr) 
 {
     GnomeDruidPageStandard *cptr_g = (GnomeDruidPageStandard *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GnomeDruidPageStandard_get_background (cptr_g));
+    return getGBoxedHandle(env, GnomeDruidPageStandard_get_background (cptr_g),
+    		GDK_TYPE_COLOR, (GBoxedCopyFunc) gdk_color_copy,
+    		(GBoxedFreeFunc) gdk_color_free);
 }
 
 GdkColor * GnomeDruidPageStandard_get_logo_background (GnomeDruidPageStandard * cptr) 
@@ -127,7 +132,9 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_DruidPageStandard_getLogoBackground
     jclass cls, jobject cptr) 
 {
     GnomeDruidPageStandard *cptr_g = (GnomeDruidPageStandard *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GnomeDruidPageStandard_get_logo_background (cptr_g));
+    return getGBoxedHandle(env, GnomeDruidPageStandard_get_logo_background (cptr_g),
+    		GDK_TYPE_COLOR, (GBoxedCopyFunc) gdk_color_copy,
+    		(GBoxedFreeFunc) gdk_color_free);
 }
 
 GdkColor * GnomeDruidPageStandard_get_contents_background (GnomeDruidPageStandard * cptr) 
@@ -143,7 +150,9 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_DruidPageStandard_getContentsBackgr
     jclass cls, jobject cptr) 
 {
     GnomeDruidPageStandard *cptr_g = (GnomeDruidPageStandard *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GnomeDruidPageStandard_get_contents_background (cptr_g));
+    return getGBoxedHandle(env, GnomeDruidPageStandard_get_contents_background (cptr_g),
+    		GDK_TYPE_COLOR, (GBoxedCopyFunc) gdk_color_copy,
+    		(GBoxedFreeFunc) gdk_color_free);
 }
 
 /*
@@ -164,7 +173,7 @@ Java_org_gnu_gnome_DruidPageStandard_gnome_1druid_1page_1standard_1get_1type (JN
 JNIEXPORT jobject JNICALL Java_org_gnu_gnome_DruidPageStandard_gnome_1druid_1page_1standard_1new (
     JNIEnv *env, jclass cls) 
 {
-    return getHandleFromPointer(env, gnome_druid_page_standard_new ());
+    return getGObjectHandle(env, G_OBJECT(gnome_druid_page_standard_new ()));
 }
 
 /*
@@ -178,8 +187,9 @@ Java_org_gnu_gnome_DruidPageStandard_gnome_1druid_1page_1standard_1new_1with_1va
     gchar* title_g = (gchar*)(*env)->GetStringUTFChars(env, title, 0);
     GdkPixbuf *logo_g = (GdkPixbuf *)getPointerFromHandle(env, logo);
     GdkPixbuf *topWatermark_g = (GdkPixbuf *)getPointerFromHandle(env, topWatermark);
-    jobject result = getHandleFromPointer(env, 
-    		gnome_druid_page_standard_new_with_vals (title_g, logo_g, topWatermark_g));
+    jobject result = getGObjectHandle(env, 
+    		G_OBJECT(gnome_druid_page_standard_new_with_vals (title_g, logo_g,
+    		topWatermark_g)));
     if (title) 
     	(*env)->ReleaseStringUTFChars(env, title, title_g);
     return result;
